<?php

namespace Drupal\stripe_subscription\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\stripe_api\StripeApiService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class StripeApiAdminForm.
 *
 * Contains admin form functionality for the Stripe API.
 */
class StripeSubscriptionAdminForm extends ConfigFormBase {

  /**
   * Stripe API service.
   *
   * @var \Drupal\stripe_api\StripeApiService
   */
  protected $stripeApi;

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\stripe_api\StripeApiService $stripe_api
   *   Stripe API service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, StripeApiService $stripe_api) {
    $this->stripeApi = $stripe_api;

    parent::__construct($config_factory);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('stripe_api.stripe_api')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'stripe_subscription_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'stripe_subscription.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('stripe_subscription.settings');
    $form['pricing_table_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pricing Table ID'),
      '#description' => $this->t('Enter the ID of the pricing table to display.'),
      '#default_value' => $config->get('pricing_table_id'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('stripe_subscription.settings')
      ->set('pricing_table_id', $form_state->getValue('pricing_table_id'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
