<?php

namespace Drupal\stripe_subscription\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\stripe_api\StripeApiService;
use Drupal\stripe_subscription\Controller\UserSubscriptionsController;
use Drupal\subscription_manager\SubscriptionManagerService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'SubscribeBlock' block.
 *
 * @Block(
 *  id = "stripe_subscribe_block",
 *  admin_label = @Translation("Stripe subscribe block")
 * )
 */
class StripeSubscribeBlock extends BlockBase implements ContainerFactoryPluginInterface {

  private UserSubscriptionsController $userSubscriptionsController;

  private ImmutableConfig $config;

  /**
   * @param array $configuration
   * @param $plugin_id
   * @param $plugin_definition
   * @param \Drupal\subscription_manager\SubscriptionManagerService $subscription_manager
   * @param \Drupal\Core\Logger\LoggerChannelInterface $logger
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   * @param \Drupal\stripe_api\StripeApiService $stripe_api
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    SubscriptionManagerService $subscription_manager,
    LoggerChannelInterface $logger,
    AccountProxyInterface $current_user,
    StripeApiService $stripe_api,
    ConfigFactoryInterface $config_factory,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->config = $config_factory->get('stripe_api.settings');
    $this->userSubscriptionsController = new UserSubscriptionsController($subscription_manager, $logger, $current_user, $stripe_api, $config_factory);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('subscription_manager'),
      $container->get('logger.channel.stripe_subscription'),
      $container->get('current_user'),
      $container->get('stripe_api.stripe_api'),
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'show_gift_toggle' => TRUE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form['show_gift_toggle'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show Gift Toggle'),
      '#description' => $this->t('Should the gift toggle be displayed?'),
      '#default_value' => $this->configuration['show_gift_toggle'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['show_gift_toggle'] = $values['show_gift_toggle'];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return $this->userSubscriptionsController->subscribe($this->configuration['show_gift_toggle']);
  }

}
